# CLI

Cadwyn has an optional CLI interface that can be installed with `pip install 'cadwyn[standard]'`.
You can run `cadwyn --version` to check current version of Cadwyn.

Its main purpose is [rendering generated schemas](./schema_generation.md#rendering-schemas).

You can also check Cadwyn's version using the CLI:

```bash
cadwyn --version
```
